pub struct TokenList {
pub name: String,
pub timestamp: DateTime<FixedOffset>,
pub version: Version,
pub logo_uri: Option<Url>,
pub keywords: Vec<String>,
pub tags: HashMap<String, Tag>,
pub tokens: Vec<Token>,
}Expand description
A list of Ethereum token metadata conforming to the token list schema.
Fields
name: StringThe name of the token list
timestamp: DateTime<FixedOffset>The timestamp of this list version; i.e. when this immutable version of the list was created
version: VersionThe version of the list, used in change detection
logo_uri: Option<Url>A URI for the logo of the token list; prefer SVG or PNG of size 256x256
keywords: Vec<String>Keywords associated with the contents of the list; may be used in list discoverability
A mapping of tag identifiers to their name and description
tokens: Vec<Token>The list of tokens included in the list